#
# spec file for package libwtcdb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libwtcdb
%define lname	libwtcdb1
Version:        20240518
Release:        1.2
Summary:        Library and tools to access Windows thumbnail cache databases
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libwtcdb
Source:         https://github.com/libyal/libwtcdb/releases/download/%version/%name-experimental-%version.tar.gz
Source2:        https://github.com/libyal/libwtcdb/releases/download/%version/%name-experimental-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  bison
BuildRequires:  c_compiler
BuildRequires:  flex
BuildRequires:  gettext-tools >= 0.18.1
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fuse) >= 2.6
BuildRequires:  pkgconfig(libbfio) >= 20240414
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcfile) >= 20240414
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcpath) >= 20240414
BuildRequires:  pkgconfig(libcsplit) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfdatetime) >= 20240415
BuildRequires:  pkgconfig(libuna) >= 20240414
# Various notes: https://en.opensuse.org/libyal

%description
libwtcdb is a library to access the Windows (Vista/7) Explorer
thumbnail cache database (WTCDB) format (thumbcache.db).

Part of the libyal family of libraries.

%package -n %lname
Summary:        Library for accessing Windows thumbnail cache databases
Group:          System/Libraries

%description -n %lname
libwtcdb is a library to access the Windows (Vista/7) Explorer
thumbnail cache database (WTCDB) format (thumbcache.db).

Part of the libyal family of libraries.

%package devel
Summary:        Development files for libwtcdb
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libwtcdb is a library to access the Windows (Vista/7) Explorer
thumbnail cache database (WTCDB) format (thumbcache.db).

This subpackage contains libraries and header files for developing
applications that want to make use of libwtcdb.

%package tools
Summary:        Utilities for reading Windows thumbnail cache databases
Group:          Productivity/File utilities

%description tools
This subpackage contains the utility programs from libwtcdb to
read Windows thumbnail cache databases.

%prep
%autosetup -p1

%build
if [ ! -e configure ]; then ./autogen.sh; fi
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
%make_build

%install
%make_install
find "%buildroot" -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libwtcdb.so.*

%files devel
%_includedir/*
%_libdir/*.so
%_libdir/pkgconfig/*.pc
%_mandir/man3/*.3*

%files tools
%_bindir/wtcdb*
%_mandir/man1/wtcdb*

%changelog
* Sun May 19 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240518
  * Added support for format versions 30, 31 and 32
- Delete system-libs.patch (only needed for git snapshots)
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Tue May 18 2021 Jan Engelhardt <jengelh@inai.de>
- Initial package for build.opensuse.org
  (version 20210417/commit 76a89105)
- Add system-libs.patch
